==> haskell-servant-swagger-1.2.1-134-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-swagger
version:              1.2.1
visibility:           public
id:                   servant-swagger-1.2.1-4np5PJuHx3BBUgRx8XEg4m
key:                  servant-swagger-1.2.1-4np5PJuHx3BBUgRx8XEg4m
license:              BSD-3-Clause
copyright:            (c) 2015-2018, Servant contributors
maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:
    https://github.com/haskell-servant/servant/tree/master/servant-swagger#readme

synopsis:
    Generate a Swagger/OpenAPI/OAS 2.0 specification for your servant API.

description:
    Swagger is a project used to describe and document RESTful APIs. The core of the
    project is the [OpenAPI Specification (OAS)](https://swagger.io/docs/specification/about/).
    This library implements v2.0 of the spec. Unlike Servant it is language-agnostic and thus is
    quite popular among developers in different languages. It has also existed for a longer time
    and has more helpful tooling.

    This package provides means to generate a Swagger/OAS specification for a Servant API
    and also to partially test whether an API conforms with its specification.

    Generated Swagger specification then can be used for many things such as

    * displaying interactive documentation using [Swagger UI](http://swagger.io/swagger-ui/);

    * generating clients and servers in many languages using [Swagger Codegen](http://swagger.io/swagger-codegen/);

    * and [many others](http://swagger.io/open-source-integrations/).

category:             Web, Servant, Swagger
abi:                  fa2126fb25658483c22ee415aa56ecd7
exposed:              True
exposed-modules:
    Servant.Swagger Servant.Swagger.Internal
    Servant.Swagger.Internal.Orphans Servant.Swagger.Internal.Test
    Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap Servant.Swagger.Test
    Servant.Swagger.TypeLevel

import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-swagger-1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-swagger-1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-swagger-1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-swagger
hs-libraries:         HSservant-swagger-1.2.1-4np5PJuHx3BBUgRx8XEg4m
depends:
    QuickCheck-2.15.0.1-3xlJoVjdvgVJR3Okie7O9R
    aeson-2.1.2.1-AErwMfn2r5g1Pc6FekWoJb
    aeson-pretty-0.8.10-HGqdLPRnyeEEY0lM8KqhKG base-4.17.2.1
    base-compat-0.14.1-EDnSvJBeGTDBBfh2KFPKKz bytestring-0.11.5.3
    hspec-2.11.3-4NdBUI01yhNBDt0uNf7DiI
    http-media-0.8.1.1-xFh3uAFxLOJdweNzh72gn
    insert-ordered-containers-0.2.5.3-HRzzwqplikYDFaoIQnA13c
    lens-5.3.2-DlnMzXp6T2vRa3tLj6rdI
    servant-0.20.3.0-QLzaldkZNeKPN91X7Nypg
    singleton-bool-0.1.8-64nvo3Ez6mZ2zFQLzNO04p
    swagger2-2.8.10-FeXXwdwiuLWHqHSwwyJyu2 text-2.0.2
    unordered-containers-0.2.20-2t1vPVJZrFoJrApu3o7oBM

haddock-interfaces:
    /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock

haddock-html:         /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-swagger-1.2.1-135-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-swagger
version:              1.2.1
visibility:           public
id:                   servant-swagger-1.2.1-I4AFJxbeel3JO2BS2tGPZ3
key:                  servant-swagger-1.2.1-I4AFJxbeel3JO2BS2tGPZ3
license:              BSD-3-Clause
copyright:            (c) 2015-2018, Servant contributors
maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:
    https://github.com/haskell-servant/servant/tree/master/servant-swagger#readme

synopsis:
    Generate a Swagger/OpenAPI/OAS 2.0 specification for your servant API.

description:
    Swagger is a project used to describe and document RESTful APIs. The core of the
    project is the [OpenAPI Specification (OAS)](https://swagger.io/docs/specification/about/).
    This library implements v2.0 of the spec. Unlike Servant it is language-agnostic and thus is
    quite popular among developers in different languages. It has also existed for a longer time
    and has more helpful tooling.

    This package provides means to generate a Swagger/OAS specification for a Servant API
    and also to partially test whether an API conforms with its specification.

    Generated Swagger specification then can be used for many things such as

    * displaying interactive documentation using [Swagger UI](http://swagger.io/swagger-ui/);

    * generating clients and servers in many languages using [Swagger Codegen](http://swagger.io/swagger-codegen/);

    * and [many others](http://swagger.io/open-source-integrations/).

category:             Web, Servant, Swagger
abi:                  fc4769ad457a858e1aefd264eeea5b42
exposed:              True
exposed-modules:
    Servant.Swagger Servant.Swagger.Internal
    Servant.Swagger.Internal.Orphans Servant.Swagger.Internal.Test
    Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap Servant.Swagger.Test
    Servant.Swagger.TypeLevel

import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-swagger-1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-swagger-1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-swagger-1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-swagger
hs-libraries:         HSservant-swagger-1.2.1-I4AFJxbeel3JO2BS2tGPZ3
depends:
    QuickCheck-2.15.0.1-K2FdhpAloErGP21S0B8fgw
    aeson-2.1.2.1-6h5MFvBT17H5yplsTy4ABm
    aeson-pretty-0.8.10-BWBr3n5fp9E4XyIlTfMbVH base-4.17.2.1
    base-compat-0.14.1-EDnSvJBeGTDBBfh2KFPKKz bytestring-0.11.5.3
    hspec-2.11.3-Knxe7Je4fHXBrfWW4dDy2s
    http-media-0.8.1.1-80YSf7aABZX5CeY9t1WlUN
    insert-ordered-containers-0.2.5.3-KpjV0VIsrAPCpfOCbqY2ip
    lens-5.3.2-Do7BRGZKCykCgu16LW7xBK
    servant-0.20.3.0-lF82iptA2PDz2IIzgvq7U
    singleton-bool-0.1.8-20VzeYntw6i2g6Ao11tIZX
    swagger2-2.8.10-Uh8rMy0rPVDZTC4dxjukf text-2.0.2
    unordered-containers-0.2.20-2N1fR83O3bC5qS2nrjaL2B

haddock-interfaces:
    /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock

haddock-html:         /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
